'''Type 'afro.help()' for help
Type 'afro.' followed by one of the folloing colors [green, red, yellow, cyan, magenta] then ("the text to add color to here") without spaces for eg. print(afro.red("This Text Is Red"))
Type 'afro.' followed by 'diflet()' which will find the amount of different letters in a string.            (string, starting_value) so afro.diflet("hellllllllllo", 1) would return 5 because 4 different letters are in that string and the second parameter would be the added value